@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 DEFAULT_MODEL = "SD-1.5"
 DEFAULT_SAMPLER = "k_dpmpp_2m"
@@ -109,7 +110,7 @@ MODEL_CONFIGS = [
         default_negative_prompt="",
         alias="edit",
     ),
-    #--- Custom model --#
+    # --- Custom model --#
     ModelConfig(
         short_name="openjourney-v1",
         config_path="configs/stable-diffusion-v1.yaml",
@@ -228,3 +229,9 @@ SAMPLER_TYPE_OPTIONS = [
     "k_euler_a",
     "k_heun",
 ]
+
+
+def get_model_config(model_name: str) -> Optional[ModelConfig]:
+    if model_name in MODEL_CONFIG_SHORTCUTS:
+        return MODEL_CONFIG_SHORTCUTS[model_name]
+    return None
